# arvestust:urls
from django.urls import include, path
from .views.urls import urlpatterns

app_name = 'arvestust'
